#ifndef _TASK_H_
#define _TASK_H_

/*! \file *********************************************************************
 *
 * \brief
 *      Headder-Datei zur task.c 
 *
 * \par Projekt:
 *      Beatmungsgeraet - Bediencontroller - TRENDvent \n
 *      Prozessor: ATmega2560 \n
 *		Frequenz: 14.7456 MHz
 *
 * \author 
 *      Hoffrichter GmbH: http://www.hoffrichter.com \n
 *      Support email: info@hoffrichter.de
 *
 * Name: Steffen Graap
 * Date: 16.12.2008  \n
 ******************************************************************************/
#include "_defs.h"

//Konstanten & Macros
#define MAX_TIME_ENTRYS		30				//!< maximale Anzahl der Eintrge in der Auftragsliste fr Zeittask
#define MAX_PRIO_ENTRYS		20				//!< maximale Anzahl der Eintrge in der Auftragsliste fr Zeittask
#define T_FREE				254				//!< Index fr freien Eintrag
#define T_LAST				255				//!< Index fr letzten gltigen Eintrag
//#define TIMER_RESOLUTION		UINT8		//!< Auflsung des Timers 8 bit (bei 2ms-Takt, max. 510 ms)
#define TIMER_RESOLUTION		UINT16		//!< Auflsung des Timers 16 bit (bei 2ms-Takt, max. 2 min 11,07 s)


typedef void (* funcp)(void);				//!< Typdefinition eines Poiters auf eine Funktion (Ohne bergabe- & Rckgabewert

//Structuren
/*! \brief Structure
 *  Elemente der Time Task Liste
 */
struct _TimeElement{
UINT8 u8NextIndex;							//!< gibt den nchsten Listeeintrag an
TIMER_RESOLUTION tT_Delta;					//!< Delta zum vorhergerigen Eintrag in T_Delta x Arbarbeitungtakt
funcp pFunktion;							//!< Pointer auf die auszufhrende Funktion 
};

/*! \brief Structure
 *  Elemente der Prio Task Liste
 */
struct _PrioElement{
UINT8 u8NextIndex;							//!< gibt den nchsten Listeeintrag an
UINT8 u8Prioritaet;							//!< Prioritt des Eintrages
funcp pFunktion;							//!< Pointer auf die auszufhrende Funktion 
};

//Funktionen
UINT8 u8Add_Time_Task (funcp pFunktion , TIMER_RESOLUTION tDelay);
UINT8 u8Remove_Time_Task (funcp pFunktion);
UINT8 u8Check_Time_Task (funcp pFunktion);
void vInit_Time_Task (void);
UINT8 u8Add_Prio_Task (funcp pFunktion , UINT8 u8Prioritaet);
UINT8 u8Remove_Prio_Task (funcp pFunktion);
UINT8 u8Check_Prio_Task (funcp pFunktion);
void vInit_Prio_Task (void);
void vTaskmanager (void);

#endif /*_TASK_H_*/
